# pmtiles

```sh
pip install pmtiles
```

## Running Tests

```sh
python -m unittest test/test_*
```

## Uploading build

```sh
python -m build
twine upload dist/*
```

## Status

For asynchronous I/O, see [aiopmtiles](https://github.com/developmentseed/aiopmtiles)
